@@ -12,15 +12,14 @@ from metricflow.model.objects.elements.dimension import DimensionType, Dimension
 from metricflow.model.objects.elements.identifier import IdentifierType
 from metricflow.model.objects.user_configured_model import UserConfiguredModel
 from metricflow.object_utils import pformat_big_objects, flatten_nested_sequence
+from metricflow.references import MeasureReference, MetricReference
 from metricflow.specs import (
-    MeasureReference,
-    LinklessIdentifierSpec,
     DEFAULT_TIME_GRANULARITY,
     LinkableSpecSet,
     DimensionSpec,
     TimeDimensionSpec,
     IdentifierSpec,
-    MetricSpec,
+    IdentifierReference,
 )
 from metricflow.time.time_granularity import TimeGranularity
 
@@ -275,7 +274,7 @@ class LinkableElementSet:
             dimension_specs=tuple(
                 DimensionSpec(
                     element_name=x.element_name,
-                    identifier_links=tuple(LinklessIdentifierSpec.from_element_name(x) for x in x.identifier_links),
+                    identifier_links=tuple(IdentifierReference(element_name=x) for x in x.identifier_links),
                 )
                 for x in self.linkable_dimensions
                 if not x.time_granularity
@@ -283,7 +282,7 @@ class LinkableElementSet:
             time_dimension_specs=tuple(
                 TimeDimensionSpec(
                     element_name=x.element_name,
-                    identifier_links=tuple(LinklessIdentifierSpec.from_element_name(x) for x in x.identifier_links),
+                    identifier_links=tuple(IdentifierReference(element_name=x) for x in x.identifier_links),
                     time_granularity=x.time_granularity,
                 )
                 for x in self.linkable_dimensions
@@ -292,7 +291,7 @@ class LinkableElementSet:
             identifier_specs=tuple(
                 IdentifierSpec(
                     element_name=x.element_name,
-                    identifier_links=tuple(LinklessIdentifierSpec.from_element_name(x) for x in x.identifier_links),
+                    identifier_links=tuple(IdentifierReference(element_name=x) for x in x.identifier_links),
                 )
                 for x in self.linkable_identifiers
             ),
@@ -583,16 +582,16 @@ class ValidLinkableSpecResolver:
 
     def get_linkable_elements_for_metrics(
         self,
-        metric_specs: Sequence[MetricSpec],
+        metric_references: Sequence[MetricReference],
         with_any_of: FrozenSet[LinkableElementProperties],
         without_any_of: FrozenSet[LinkableElementProperties],
     ) -> LinkableElementSet:
         """Gets the valid linkable elements that are common to all requested metrics."""
         linkable_element_sets = []
-        for metric_spec in metric_specs:
-            element_sets = self._metric_to_linkable_element_sets.get(metric_spec.element_name)
+        for metric_reference in metric_references:
+            element_sets = self._metric_to_linkable_element_sets.get(metric_reference.element_name)
             if not element_sets:
-                raise ValueError(f"Unknown metric: {metric_spec} in element set")
+                raise ValueError(f"Unknown metric: {metric_reference} in element set")
             metric_result = LinkableElementSet.intersection(
                 [x.filter(with_any_of=with_any_of, without_any_of=without_any_of) for x in element_sets]
             )
